.. garage documentation master file, created by
   sphinx-quickstart on Mon Feb 15 20:07:12 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to garage
=================

garage is a framework for developing and evaluating reinforcement learning algorithms.

garage is a work in progress, input is welcome. The available documentation is limited for now.

User Guide
==========

The garage user guide explains how to install garage, how to run experiments, and how to implement new MDPs and new algorithms.

.. toctree::
   :maxdepth: 2

   user/installation
   user/experiments
   user/implement_env
   user/implement_algo_basic
   user/implement_algo_advanced


Citing garage
=============

If you use garage for academic research, you are highly encouraged to cite the following paper:

- Yan Duan, Xi Chen, Rein Houthooft, John Schulman, Pieter Abbeel. "`Benchmarking Deep Reinforcement Learning for Continuous Control <http://arxiv.org/abs/1604.06778>`_. *Proceedings of the 33rd International Conference on Machine Learning (ICML), 2016.*


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
